aboutsummaryrefslogtreecommitdiff
path: root/cutter.go
diff options
context:
space:
mode:
Diffstat (limited to 'cutter.go')
-rw-r--r--cutter.go9
1 files changed, 5 insertions, 4 deletions
diff --git a/cutter.go b/cutter.go
index d26d534..a565959 100644
--- a/cutter.go
+++ b/cutter.go
@@ -52,11 +52,12 @@ func NewCutter(io *bufio.ReadWriter, o Orientation) Cutter {
c.Initialize()
if !c.Ready() {
fmt.Println("not ready")
+ time.Sleep(time.Second)
}
- c.CR() // Home
+ c.GoHome() // Home
v, _ := c.Version()
- fmt.Println("Craft ROBO Ver.", v)
+ fmt.Println(craftRobo, "Ver.", v)
pen := MediaID[113]
c.MediaType(pen.ID)
@@ -113,8 +114,8 @@ func (c Cutter) TestCut() {
c.Send("FH")
}
-// CR returns carret to home on same line
-func (c Cutter) CR() {
+// GoHome returns carret to home on same line
+func (c Cutter) GoHome() {
c.Send("TT")
}